@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -29,35 +29,47 @@ $this->includeJsFile(($data['action'] === 'user.edit')
 	: 'administration.userprofile.edit.js.php'
 );
 
-$widget = new CWidget();
+$html_page = new CHtmlPage();
 
 if ($data['action'] === 'user.edit') {
 	$widget_name = _('Users');
-	$doc_url = CDocHelper::ADMINISTRATION_USER_EDIT;
+	$doc_url = CDocHelper::USERS_USER_EDIT;
+	$csrf_token = CCsrfTokenHelper::get('user');
 }
 else {
 	$widget_name = _('User profile').NAME_DELIMITER;
 	$widget_name .= ($data['name'] !== '' || $data['surname'] !== '')
 		? $data['name'].' '.$data['surname']
 		: $data['username'];
-	$widget->setTitleSubmenu(getUserSettingsSubmenu());
-	$doc_url = CDocHelper::ADMINISTRATION_USERPROFILE_EDIT;
+	$html_page->setTitleSubmenu(getUserSettingsSubmenu());
+	$doc_url = CDocHelper::USERS_USERPROFILE_EDIT;
+	$csrf_token = CCsrfTokenHelper::get('userprofile');
 }
 
-$widget
+$html_page
 	->setTitle($widget_name)
 	->setDocUrl(CDocHelper::getUrl($doc_url));
+
 $tabs = new CTabView();
 
 if ($data['form_refresh'] == 0) {
 	$tabs->setSelected(0);
 }
 
+if ($data['readonly'] == true) {
+	CMessageHelper::addWarning(
+		_('This user is IdP provisioned. Manual changes for provisioned fields are not allowed.')
+	);
+	show_messages();
+}
+
 // Create form.
 $user_form = (new CForm())
+	->addItem((new CVar('form_refresh', $data['form_refresh'] + 1))->removeId())
+	->addItem((new CVar(CCsrfTokenHelper::CSRF_TOKEN_NAME, $csrf_token))->removeId())
 	->setId('user-form')
 	->setName('user_form')
-	->setAttribute('aria-labelledby', ZBX_STYLE_PAGE_TITLE)
+	->setAttribute('aria-labelledby', CHtmlPage::PAGE_TITLE_ID)
 	->addVar('action', $data['action'])
 	->addVar('userid', $data['userid']);
 
@@ -68,7 +80,7 @@ if ($data['action'] === 'user.edit') {
 	$user_form_list
 		->addRow((new CLabel(_('Username'), 'username'))->setAsteriskMark(),
 			(new CTextBox('username', $data['username']))
-				->setReadonly($data['db_user']['username'] === ZBX_GUEST_USER)
+				->setReadonly($data['db_user']['username'] === ZBX_GUEST_USER || $data['readonly'])
 				->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 				->setAriaRequired()
 				->setAttribute('autofocus', 'autofocus')
@@ -78,18 +90,21 @@ if ($data['action'] === 'user.edit') {
 			(new CTextBox('name', $data['name']))
 				->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 				->setAttribute('maxlength', DB::getFieldLength('users', 'name'))
+				->setReadonly($data['readonly'])
 		)
 		->addRow(_('Last name'),
 			(new CTextBox('surname', $data['surname']))
 				->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 				->setAttribute('maxlength', DB::getFieldLength('users', 'surname'))
+				->setReadonly($data['readonly'])
 		)
 		->addRow(
-			(new CLabel(_('Groups'), 'user_groups__ms'))->setAsteriskMark(),
+			new CLabel(_('Groups'), 'user_groups__ms'),
 			(new CMultiSelect([
 				'name' => 'user_groups[]',
 				'object_name' => 'usersGroups',
 				'data' => $data['groups'],
+				'disabled' => $data['readonly'],
 				'popup' => [
 					'parameters' => [
 						'srctbl' => 'usrgrp',
@@ -107,14 +122,6 @@ if ($data['action'] === 'user.edit') {
 if ($data['change_password']) {
 	$user_form->disablePasswordAutofill();
 
-	$password1 = (new CPassBox('password1', $data['password1']))
-		->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
-		->setAriaRequired();
-
-	if ($data['action'] !== 'user.edit') {
-		$password1->setAttribute('autofocus', 'autofocus');
-	}
-
 	$password_requirements = [];
 
 	if ($data['password_requirements']['min_length'] > 1) {
@@ -157,13 +164,28 @@ if ($data['change_password']) {
 		])
 		: null;
 
+	$current_password = (new CPassBox('current_password'))
+		->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
+		->setAriaRequired();
+
+	if ($data['action'] !== 'user.edit') {
+		$current_password->setAttribute('autofocus', 'autofocus');
+	}
+
+	if (CWebUser::$data['userid'] == $data['userid']) {
+		$user_form_list
+			->addRow((new CLabel(_('Current password'), 'current_password'))->setAsteriskMark(), $current_password);
+	}
+
 	$user_form_list
 		->addRow((new CLabel([_('Password'), $password_hint_icon], 'password1'))->setAsteriskMark(), [
 			// Hidden dummy login field for protection against chrome error when password autocomplete.
 			(new CInput('text', null, null))
 				->setAttribute('tabindex', '-1')
 				->addStyle('position: absolute; left: -100vw;'),
-			$password1
+			(new CPassBox('password1', $data['password1']))
+				->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
+				->setAriaRequired()
 		])
 		->addRow((new CLabel(_('Password (once again)'), 'password2'))->setAsteriskMark(),
 			(new CPassBox('password2', $data['password2']))
@@ -173,13 +195,25 @@ if ($data['change_password']) {
 		->addRow('', _('Password is not mandatory for non internal authentication type.'));
 }
 else {
-	$user_form_list->addRow(_('Password'),
+	$change_password_enabled = !$data['readonly'] && $data['internal_auth'];
+
+	if ($change_password_enabled && $data['action'] === 'user.edit') {
+		$change_password_enabled = $data['db_user']['username'] !== ZBX_GUEST_USER;
+	}
+
+	$hint = !$change_password_enabled
+		? $hint = (makeErrorIcon(_('Password can only be changed for users using the internal Zabbix authentication.')))
+			->addStyle('margin-left: 5px; margin-top: 4px')
+		: null;
+
+	$user_form_list->addRow(_('Password'), [
 		(new CSimpleButton(_('Change password')))
-			->setEnabled($data['action'] === 'userprofile.edit' || $data['db_user']['username'] !== ZBX_GUEST_USER)
+			->setEnabled($change_password_enabled)
 			->setAttribute('autofocus', 'autofocus')
 			->onClick('submitFormWithParam("'.$user_form->getName().'", "change_password", "1");')
-			->addClass(ZBX_STYLE_BTN_GREY)
-	);
+			->addClass(ZBX_STYLE_BTN_GREY),
+		$hint
+	]);
 }
 
 // Append languages, timezones & themes to form list.
@@ -302,17 +336,28 @@ if ($data['action'] === 'user.edit' || CWebUser::$data['type'] > USER_TYPE_ZABBI
 		->setHeader([_('Type'), _('Send to'), _('When active'), _('Use if severity'), _('Status'), _('Action')]);
 
 	foreach ($data['medias'] as $index => $media) {
-		if ($media['active'] == MEDIA_STATUS_ACTIVE) {
-			$status = (new CLink(_('Enabled'), '#'))
-				->onClick('return create_var("'.$user_form->getName().'","disable_media",'.$index.', true);')
-				->addClass(ZBX_STYLE_LINK_ACTION)
-				->addClass(ZBX_STYLE_GREEN);
+		if ($data['mediatypes'][$media['mediatypeid']]['status'] == MEDIA_TYPE_STATUS_ACTIVE) {
+			$media_name = $media['name'];
+
+			if ($media['active'] == MEDIA_STATUS_ACTIVE) {
+				$status_action = 'return create_var("'.$user_form->getName().'","disable_media",'.$index.', true);';
+				$status_label = _('Enabled');
+				$status_class = ZBX_STYLE_GREEN;
+			}
+			else {
+				$status_action = 'return create_var("'.$user_form->getName().'","enable_media",'.$index.', true);';
+				$status_label = _('Disabled');
+				$status_class = ZBX_STYLE_RED;
+			}
+
+			$status = (new CSimpleButton($status_label))
+				->onClick(!$data['readonly'] ? $status_action : null)
+				->addClass(ZBX_STYLE_BTN_LINK.($data['readonly'] ? '' : ' '.$status_class))
+				->setEnabled(!$data['readonly']);
 		}
 		else {
-			$status = (new CLink(_('Disabled'), '#'))
-				->onClick('return create_var("'.$user_form->getName().'","enable_media",'.$index.', true);')
-				->addClass(ZBX_STYLE_LINK_ACTION)
-				->addClass(ZBX_STYLE_RED);
+			$media_name = new CDiv([$media['name'], makeWarningIcon(_('Media type disabled by Administration.'))]);
+			$status = (new CDiv(_('Disabled')))->addClass(ZBX_STYLE_RED);
 		}
 
 		$parameters = [
@@ -349,7 +394,7 @@ if ($data['action'] === 'user.edit' || CWebUser::$data['type'] > USER_TYPE_ZABBI
 
 		$media_table_info->addRow(
 			(new CRow([
-				$media['name'],
+				$media_name,
 				$media['sendto'],
 				(new CDiv($media['period']))
 					->setAttribute('style', 'max-width: '.ZBX_TEXTAREA_STANDARD_WIDTH.'px;')
@@ -359,10 +404,14 @@ if ($data['action'] === 'user.edit' || CWebUser::$data['type'] > USER_TYPE_ZABBI
 				(new CCol(
 					new CHorList([
 						(new CButton(null, _('Edit')))
+							->setEnabled(!$data['readonly'])
 							->addClass(ZBX_STYLE_BTN_LINK)
 							->setAttribute('data-parameters', json_encode($parameters))
-							->onClick('PopUp("popup.media", JSON.parse(this.dataset.parameters));'),
+							->onClick('PopUp("popup.media", JSON.parse(this.dataset.parameters),
+								{dialogue_class: "modal-popup-generic"});'
+							),
 						(new CButton(null, _('Remove')))
+							->setEnabled(!$data['readonly'])
 							->addClass(ZBX_STYLE_BTN_LINK)
 							->onClick('removeMedia('.$index.');')
 					])
@@ -375,8 +424,12 @@ if ($data['action'] === 'user.edit' || CWebUser::$data['type'] > USER_TYPE_ZABBI
 		(new CDiv([
 			$media_table_info,
 			(new CButton(null, _('Add')))
-				->onClick('PopUp("popup.media", '.json_encode(['dstfrm' => $user_form->getName()]).');')
+				->onClick('PopUp("popup.media", '.
+					json_encode(['dstfrm' => $user_form->getName()]).
+					', {dialogue_class: "modal-popup-generic"});'
+				)
 				->addClass(ZBX_STYLE_BTN_LINK)
+				->setEnabled(!$data['readonly'])
 		]))
 			->addClass(ZBX_STYLE_TABLE_FORMS_SEPARATOR)
 			->setAttribute('style', 'min-width: '.ZBX_TEXTAREA_BIG_WIDTH.'px;')
@@ -389,12 +442,15 @@ if ($data['action'] === 'user.edit' || CWebUser::$data['type'] > USER_TYPE_ZABBI
 if ($data['action'] === 'user.edit') {
 	$permissions_form_list = new CFormList('permissionsFormList');
 
+	$role_disabled = $data['userid'] != 0 && bccomp(CWebUser::$data['userid'], $data['userid']) == 0;
+	$role_disabled |= $data['readonly'];
+
 	$role_multiselect = (new CMultiSelect([
 		'name' => 'roleid',
 		'object_name' => 'roles',
 		'data' => $data['role'],
 		'multiple' => false,
-		'disabled' => $data['userid'] != 0 && bccomp(CWebUser::$data['userid'], $data['userid']) == 0,
+		'disabled' => $role_disabled,
 		'popup' => [
 			'parameters' => [
 				'srctbl' => 'roles',
@@ -406,7 +462,7 @@ if ($data['action'] === 'user.edit') {
 	]))->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH);
 
 	if ($data['userid'] != 0 && bccomp(CWebUser::$data['userid'], $data['userid']) == 0) {
-		$permissions_form_list->addRow((new CLabel(_('Role')))->setAsteriskMark(),
+		$permissions_form_list->addRow(new CLabel(_('Role')),
 			(new CDiv([
 				$role_multiselect,
 				new CDiv(_('User cannot change own role.'))
@@ -416,7 +472,9 @@ if ($data['action'] === 'user.edit') {
 		);
 	}
 	else {
-		$permissions_form_list->addRow((new CLabel(_('Role'), 'roleid_ms'))->setAsteriskMark(), $role_multiselect);
+		$permissions_form_list->addRow((new CLabel(_('Role'), 'roleid_ms'))->setAsteriskMark($data['roleid_required']),
+			$role_multiselect
+		);
 	}
 
 	if ($data['roleid']) {
@@ -437,7 +495,7 @@ if ($data['action'] === 'user.edit') {
 				if (array_key_exists('grouped', $group_rights) && $group_rights['grouped']) {
 					$group_name = ($groupid == 0)
 						? italic(_('All groups'))
-						: [$group_rights['name'], '&nbsp;', italic('('._('including subgroups').')')];
+						: [$group_rights['name'], NBSP(), italic('('._('including subgroups').')')];
 				}
 				else {
 					$group_name = $group_rights['name'];
@@ -450,7 +508,7 @@ if ($data['action'] === 'user.edit') {
 				if (array_key_exists('grouped', $group_rights) && $group_rights['grouped']) {
 					$group_name = ($groupid == 0)
 						? italic(_('All groups'))
-						: [$group_rights['name'], '&nbsp;', italic('('._('including subgroups').')')];
+						: [$group_rights['name'], NBSP(), italic('('._('including subgroups').')')];
 				}
 				else {
 					$group_name = $group_rights['name'];
@@ -598,11 +656,12 @@ if ($data['action'] === 'user.edit') {
 		else {
 			$elements = [];
 
-			foreach ($data['modules'] as $moduleid => $module) {
-				$elements[] = (new CSpan($module['id']))->addClass(
-					CRoleHelper::checkAccess('modules.module.'.$moduleid, $data['roleid'])
-						? ZBX_STYLE_STATUS_GREEN
-						: ZBX_STYLE_STATUS_GREY
+			foreach ($data['modules'] as $moduleid => $module_name) {
+				$elements[] = (new CSpan($module_name))->addClass(
+					array_key_exists($moduleid, $data['disabled_moduleids'])
+							|| $data['modules_rules'][$moduleid] == MODULE_STATUS_DISABLED
+						? ZBX_STYLE_STATUS_GREY
+						: ZBX_STYLE_STATUS_GREEN
 				);
 			}
 
@@ -779,8 +838,10 @@ if ($data['action'] === 'user.edit') {
 		$tabs->setFooter(makeFormFooter(
 			(new CSubmitButton(_('Update'), 'action', 'user.update'))->setId('update'),
 			[
-				(new CRedirectButton(_('Delete'),
-					'zabbix.php?action=user.delete&sid='.$data['sid'].'&userids[]='.$data['userid'],
+				(new CRedirectButton(_('Delete'), (new CUrl('zabbix.php'))
+					->setArgument('action', 'user.delete')
+					->setArgument('userids', [$data['userid']])
+					->setArgument(CCsrfTokenHelper::CSRF_TOKEN_NAME, $csrf_token),
 					_('Delete selected user?')
 				))
 					->setEnabled(bccomp(CWebUser::$data['userid'], $data['userid']) != 0)
@@ -807,6 +868,19 @@ else {
 
 // Append tab to form.
 $user_form->addItem($tabs);
-$widget
+$html_page
 	->addItem($user_form)
 	->show();
+
+if ($data['action'] === 'user.edit') {
+	(new CScriptTag('view.init('.json_encode([
+		'userid' => $data['userid'] ?: null
+	]).');'))
+		->setOnDocumentReady()
+		->show();
+}
+else {
+	(new CScriptTag('view.init();'))
+		->setOnDocumentReady()
+		->show();
+}
