@@ -1,7 +1,7 @@
 <?php declare(strict_types = 0);
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -26,8 +26,10 @@
 
 // Create form.
 $form = (new CForm())
+	->addItem((new CVar(CCsrfTokenHelper::CSRF_TOKEN_NAME, CCsrfTokenHelper::get(
+		$data['prototype'] ? 'triggerprototype' : 'trigger'
+	)))->removeId())
 	->setId('massupdate-form')
-	->setAttribute('aria-labeledby', ZBX_STYLE_PAGE_TITLE)
 	->addVar('action', $data['prototype'] ? 'popup.massupdate.triggerprototype' : 'popup.massupdate.trigger')
 	->addVar('ids', $data['ids'])
 	->addVar('update', '1')
@@ -46,22 +48,19 @@ $form = (new CForm())
  */
 $trigger_form_list = (new CFormList('trigger-form-list'))
 	->addRow(
-		(new CVisibilityBox('visible[priority]', 'priority-div', _('Original')))
+		(new CVisibilityBox('visible[priority]', 'priority', _('Original')))
 			->setLabel(_('Severity'))
 			->setAttribute('autofocus', 'autofocus'),
-		(new CDiv(
-			new CSeverity('priority', 0)
-		))->setId('priority-div')
+		(new CSeverity('priority'))->setId('priority')
 	)
 	->addRow(
-		(new CVisibilityBox('visible[manual_close]', 'manual-close-div', _('Original')))
+		(new CVisibilityBox('visible[manual_close]', 'manual-close', _('Original')))
 			->setLabel(_('Allow manual close')),
-		(new CDiv(
-			(new CRadioButtonList('manual_close', ZBX_TRIGGER_MANUAL_CLOSE_NOT_ALLOWED))
-				->addValue(_('No'), ZBX_TRIGGER_MANUAL_CLOSE_NOT_ALLOWED)
-				->addValue(_('Yes'), ZBX_TRIGGER_MANUAL_CLOSE_ALLOWED)
-				->setModern(true)
-		))->setId('manual-close-div')
+		(new CRadioButtonList('manual_close', ZBX_TRIGGER_MANUAL_CLOSE_NOT_ALLOWED))
+			->setId('manual-close')
+			->addValue(_('No'), ZBX_TRIGGER_MANUAL_CLOSE_NOT_ALLOWED)
+			->addValue(_('Yes'), ZBX_TRIGGER_MANUAL_CLOSE_ALLOWED)
+			->setModern(true)
 	);
 
 /*
@@ -69,7 +68,7 @@ $trigger_form_list = (new CFormList('trigger-form-list'))
  */
 $tags_form_list = (new CFormList('tags-form-list'))
 	->addRow(
-		(new CVisibilityBox('visible[tags]', 'tags-div', _('Original')))->setLabel(_('Tags')),
+		(new CVisibilityBox('visible[tags]', 'tags-field', _('Original')))->setLabel(_('Tags')),
 		(new CDiv([
 			(new CRadioButtonList('mass_update_tags', ZBX_ACTION_ADD))
 				->addValue(_('Add'), ZBX_ACTION_ADD)
@@ -79,8 +78,8 @@ $tags_form_list = (new CFormList('tags-form-list'))
 				->addStyle('margin-bottom: 10px;'),
 			renderTagTable([['tag' => '', 'value' => '']])
 				->setHeader([_('Name'), _('Value'), _('Action')])
-				->setId('tags-table')
-		]))->setId('tags-div')
+				->addClass('tags-table')
+		]))->setId('tags-field')
 	);
 
 /*
@@ -171,9 +170,9 @@ if ($data['context'] === 'template') {
 }
 
 $dependencies_form_list->addRow(
-	(new CVisibilityBox('visible[dependencies]', 'dependencies-div', _('Original')))
+	(new CVisibilityBox('visible[dependencies]', 'dependencies-field', _('Original')))
 		->setLabel(_('Replace dependencies')),
-	(new CDiv([$dependencies_table, new CHorList($buttons)]))->setId('dependencies-div')
+	(new CDiv([$dependencies_table, new CHorList($buttons)]))->setId('dependencies-field')
 );
 
 // Append tabs to the form.
