@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -23,16 +23,16 @@
  * @var CView $this
  */
 $form = (new CForm())
+	->addItem((new CVar(CCsrfTokenHelper::CSRF_TOKEN_NAME, CCsrfTokenHelper::get('valuemap')))->removeId())
 	->setId('valuemap-edit-form')
 	->setName('valuemap-edit-form')
 	->addVar('action', $data['action'])
 	->addVar('update', 1)
 	->addVar('source-name', $data['name'])
-	->addItem(new CJsScript($this->readJsFile('../../../include/views/js/editabletable.js.php')))
-	->addItem((new CInput('submit', 'submit'))
-		->addStyle('display: none;')
-		->removeId()
-	);
+	->addItem(new CJsScript($this->readJsFile('../../../include/views/js/editabletable.js.php')));
+
+// Enable form submitting on Enter.
+$form->addItem((new CSubmitButton(null))->addClass(ZBX_STYLE_FORM_SUBMIT_HIDDEN));
 
 if ($data['valuemapid']) {
 	$form->addVar('valuemapid', $data['valuemapid']);
@@ -46,7 +46,7 @@ foreach (array_values($data['valuemap_names']) as $index => $name) {
 	$form->addVar('valuemap_names['.$index.']', $name);
 }
 
-$form_grid = (new CFormGrid())->addClass(CFormGrid::ZBX_STYLE_FORM_GRID_1_1);
+$form_grid = new CFormGrid();
 
 $header_row = ['', _('Type'), _('Value'), '', _('Mapped to'), _('Action'), ''];
 $mappings = (new CDiv([
@@ -84,7 +84,7 @@ $mappings->addItem(
 				])),
 			(new CTextBox('mappings[#{index}][value]', '#{value}', false, DB::getFieldLength('valuemap_mapping', 'value')))
 				->setWidth(ZBX_TEXTAREA_SMALL_WIDTH),
-			'&rArr;',
+			RARR(),
 			(new CTextBox('mappings[#{index}][newvalue]', '#{newvalue}', false, DB::getFieldLength('valuemap_mapping', 'newvalue')))
 				->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
 				->setAriaRequired(),
@@ -101,20 +101,18 @@ $mappings->addItem($mappings_data);
 $form_grid
 	->addItem([
 		(new CLabel(_('Name'), 'name'))->setAsteriskMark(),
-		(new CFormField(
+		new CFormField(
 			(new CTextBox('name', $data['name'], false, DB::getFieldLength('valuemap', 'name')))
 				->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 				->setAttribute('autofocus', 'autofocus')
 				->setAriaRequired()
-		))->addClass(CFormField::ZBX_STYLE_FORM_FIELD_FLUID)
+		)
 	])
 	->addItem([
 		(new CLabel(_('Mappings'), 'mappings'))->setAsteriskMark(),
-		(new CFormField(
-			(new CDiv($mappings))
-				->addStyle('width: 100%;')
-				->addClass('table-forms-separator')
-		))->addClass(CFormField::ZBX_STYLE_FORM_FIELD_FLUID)
+		new CFormField(
+			(new CDiv($mappings))->addClass('table-forms-separator')
+		)
 	]);
 
 $form->addItem($form_grid);
