@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -697,7 +697,7 @@ class CDRule extends CApiService {
 			$drule['druleid'] = $druleids[$index];
 		});
 
-		$this->addAuditBulk(AUDIT_ACTION_ADD, AUDIT_RESOURCE_DISCOVERY_RULE, $drules);
+		$this->addAuditBulk(CAudit::ACTION_ADD, CAudit::RESOURCE_DISCOVERY_RULE, $drules);
 
 		$create_dchecks = [];
 		foreach ($drules as $dnum => $drule) {
@@ -764,10 +764,6 @@ class CDRule extends CApiService {
 
 			// Update drule if it's modified.
 			if (DB::recordModified('drules', $db_drule, $drule)) {
-				if (array_key_exists('delay', $drule) && $db_drule['delay'] != $drule['delay']) {
-					$drule['nextcheck'] = 0;
-				}
-
 				DB::updateByPk('drules', $drule['druleid'], $drule);
 			}
 
@@ -802,7 +798,7 @@ class CDRule extends CApiService {
 			}
 		}
 
-		$this->addAuditBulk(AUDIT_ACTION_UPDATE, AUDIT_RESOURCE_DISCOVERY_RULE, $drules, $db_drules);
+		$this->addAuditBulk(CAudit::ACTION_UPDATE, CAudit::RESOURCE_DISCOVERY_RULE, $drules, $db_drules);
 
 		return ['druleids' => $druleids];
 	}
@@ -838,7 +834,7 @@ class CDRule extends CApiService {
 			'SELECT a.name,c.value'.
 			' FROM actions a,conditions c'.
 			' WHERE a.actionid=c.actionid'.
-				' AND c.conditiontype='.CONDITION_TYPE_DRULE.
+				' AND c.conditiontype='.ZBX_CONDITION_TYPE_DRULE.
 				' AND '.dbConditionString('c.value', $druleids),
 			1
 		);
@@ -855,7 +851,7 @@ class CDRule extends CApiService {
 			' FROM actions a,conditions c,dchecks dc'.
 			' WHERE a.actionid=c.actionid'.
 				' AND '.zbx_dbcast_2bigint('c.value').'=dc.dcheckid'.
-				' AND c.conditiontype='.CONDITION_TYPE_DCHECK.
+				' AND c.conditiontype='.ZBX_CONDITION_TYPE_DCHECK.
 				' AND '.dbConditionString('dc.druleid', $druleids),
 			1
 		);
@@ -866,9 +862,10 @@ class CDRule extends CApiService {
 			));
 		}
 
+		DB::delete('dchecks', ['druleid' => $druleids]);
 		DB::delete('drules', ['druleid' => $druleids]);
 
-		$this->addAuditBulk(AUDIT_ACTION_DELETE, AUDIT_RESOURCE_DISCOVERY_RULE, $db_drules);
+		$this->addAuditBulk(CAudit::ACTION_DELETE, CAudit::RESOURCE_DISCOVERY_RULE, $db_drules);
 
 		return ['druleids' => $druleids];
 	}
@@ -885,7 +882,7 @@ class CDRule extends CApiService {
 		$dbActions = DBselect(
 			'SELECT DISTINCT c.actionid'.
 			' FROM conditions c'.
-			' WHERE c.conditiontype='.CONDITION_TYPE_DCHECK.
+			' WHERE c.conditiontype='.ZBX_CONDITION_TYPE_DCHECK.
 				' AND '.dbConditionString('c.value', $dCheckIds).
 			' ORDER BY c.actionid'
 		);
@@ -901,7 +898,7 @@ class CDRule extends CApiService {
 			]);
 
 			DB::delete('conditions', [
-				'conditiontype' => CONDITION_TYPE_DCHECK,
+				'conditiontype' => ZBX_CONDITION_TYPE_DCHECK,
 				'value' => $dCheckIds
 			]);
 		}
