@@ -18,8 +18,8 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
-define('ZABBIX_VERSION',		'6.4.7');
-define('ZABBIX_API_VERSION',	'6.4.7');
+define('ZABBIX_VERSION',		'6.4.9');
+define('ZABBIX_API_VERSION',	'6.4.9');
 define('ZABBIX_EXPORT_VERSION',	'6.4');
 
 define('ZABBIX_DB_VERSION',		6040000);
@@ -178,7 +178,7 @@ define('ZBX_DB_EXTENSION_TIMESCALEDB', 'timescaledb');
 
 define('ZBX_EXT_ERR_UNDEFINED',							0);
 define('ZBX_EXT_SUCCEED',								1);
-define('ZBX_TIMESCALEDB_POSTGRES_TOO_OLD',				2);
+//define('ZBX_TIMESCALEDB_POSTGRES_TOO_OLD',				2); obsoleted since Zabbix 7.0
 define('ZBX_TIMESCALEDB_VERSION_FAILED_TO_RETRIEVE',	3);
 define('ZBX_TIMESCALEDB_VERSION_LOWER_THAN_MINIMUM',	4);
 define('ZBX_TIMESCALEDB_VERSION_NOT_SUPPORTED',			5);
@@ -263,32 +263,32 @@ define('ZBX_TCP_HEADER',			ZBX_TCP_HEADER_DATA.ZBX_TCP_HEADER_VERSION);
 define('ZBX_TCP_HEADER_LEN',		5);
 define('ZBX_TCP_DATALEN_LEN',		8);
 
-define('CONDITION_TYPE_HOST_GROUP',			0);
-define('CONDITION_TYPE_HOST',				1);
-define('CONDITION_TYPE_TRIGGER',			2);
-define('CONDITION_TYPE_TRIGGER_NAME',		3);
-define('CONDITION_TYPE_TRIGGER_SEVERITY',	4);
-define('CONDITION_TYPE_TIME_PERIOD',		6);
-define('CONDITION_TYPE_DHOST_IP',			7);
-define('CONDITION_TYPE_DSERVICE_TYPE',		8);
-define('CONDITION_TYPE_DSERVICE_PORT',		9);
-define('CONDITION_TYPE_DSTATUS',			10);
-define('CONDITION_TYPE_DUPTIME',			11);
-define('CONDITION_TYPE_DVALUE',				12);
-define('CONDITION_TYPE_TEMPLATE',			13);
-define('CONDITION_TYPE_EVENT_ACKNOWLEDGED',	14);
-define('CONDITION_TYPE_SUPPRESSED',			16);
-define('CONDITION_TYPE_DRULE',				18);
-define('CONDITION_TYPE_DCHECK',				19);
-define('CONDITION_TYPE_PROXY',				20);
-define('CONDITION_TYPE_DOBJECT',			21);
-define('CONDITION_TYPE_HOST_NAME',			22);
-define('CONDITION_TYPE_EVENT_TYPE',			23);
-define('CONDITION_TYPE_HOST_METADATA',		24);
-define('CONDITION_TYPE_EVENT_TAG',			25);
-define('CONDITION_TYPE_EVENT_TAG_VALUE',	26);
-define('CONDITION_TYPE_SERVICE',			27);
-define('CONDITION_TYPE_SERVICE_NAME',		28);
+define('ZBX_CONDITION_TYPE_HOST_GROUP',			0);
+define('ZBX_CONDITION_TYPE_HOST',				1);
+define('ZBX_CONDITION_TYPE_TRIGGER',			2);
+define('ZBX_CONDITION_TYPE_EVENT_NAME',			3);
+define('ZBX_CONDITION_TYPE_TRIGGER_SEVERITY',	4);
+define('ZBX_CONDITION_TYPE_TIME_PERIOD',		6);
+define('ZBX_CONDITION_TYPE_DHOST_IP',			7);
+define('ZBX_CONDITION_TYPE_DSERVICE_TYPE',		8);
+define('ZBX_CONDITION_TYPE_DSERVICE_PORT',		9);
+define('ZBX_CONDITION_TYPE_DSTATUS',			10);
+define('ZBX_CONDITION_TYPE_DUPTIME',			11);
+define('ZBX_CONDITION_TYPE_DVALUE',				12);
+define('ZBX_CONDITION_TYPE_TEMPLATE',			13);
+define('ZBX_CONDITION_TYPE_EVENT_ACKNOWLEDGED',	14);
+define('ZBX_CONDITION_TYPE_SUPPRESSED',			16);
+define('ZBX_CONDITION_TYPE_DRULE',				18);
+define('ZBX_CONDITION_TYPE_DCHECK',				19);
+define('ZBX_CONDITION_TYPE_PROXY',				20);
+define('ZBX_CONDITION_TYPE_DOBJECT',			21);
+define('ZBX_CONDITION_TYPE_HOST_NAME',			22);
+define('ZBX_CONDITION_TYPE_EVENT_TYPE',			23);
+define('ZBX_CONDITION_TYPE_HOST_METADATA',		24);
+define('ZBX_CONDITION_TYPE_EVENT_TAG',			25);
+define('ZBX_CONDITION_TYPE_EVENT_TAG_VALUE',	26);
+define('ZBX_CONDITION_TYPE_SERVICE',			27);
+define('ZBX_CONDITION_TYPE_SERVICE_NAME',		28);
 
 define('CONDITION_OPERATOR_EQUAL',		0);
 define('CONDITION_OPERATOR_NOT_EQUAL',	1);
@@ -2003,6 +2003,7 @@ define('ZBX_STYLE_LINK_ALT', 'link-alt');
 define('ZBX_STYLE_LIST_CHECK_RADIO', 'list-check-radio');
 define('ZBX_STYLE_LIST_DASHED', 'list-dashed');
 define('ZBX_STYLE_LIST_TABLE', 'list-table');
+define('ZBX_STYLE_LIST_TABLE_FIXED', 'fixed');
 define('ZBX_STYLE_LIST_TABLE_ACTIONS', 'list-table-actions');
 define('ZBX_STYLE_LIST_TABLE_FOOTER', 'list-table-footer');
 define('ZBX_STYLE_LIST_TABLE_STICKY_HEADER', 'sticky-header');
@@ -2102,6 +2103,7 @@ define('ZBX_STYLE_SUBFILTER', 'subfilter');
 define('ZBX_STYLE_SUBFILTER_ENABLED', 'subfilter-enabled');
 define('ZBX_STYLE_TABLE', 'table');
 define('ZBX_STYLE_TABLE_FORMS', 'table-forms');
+define('ZBX_STYLE_TABLE_SUBFORMS', 'table-subforms');
 define('ZBX_STYLE_TABLE_FORMS_CONTAINER', 'table-forms-container');
 define('ZBX_STYLE_TABLE_FORMS_SECOND_COLUMN', 'table-forms-second-column');
 define('ZBX_STYLE_TABLE_FORMS_TD_LEFT', 'table-forms-td-left');
@@ -2113,6 +2115,7 @@ define('ZBX_STYLE_TABLE_STATS', 'table-stats');
 define('ZBX_STYLE_TABS_NAV', 'tabs-nav');
 define('ZBX_STYLE_TAG', 'tag');
 define('ZBX_STYLE_TEXT_PLACEHOLDER', 'text-placeholder');
+define('ZBX_STYLE_TEXT_VERTICAL', 'text-vertical');
 define('ZBX_STYLE_TEXTAREA_FLEXIBLE', 'textarea-flexible');
 define('ZBX_STYLE_TEXTAREA_FLEXIBLE_CONTAINER', 'textarea-flexible-container');
 define('ZBX_STYLE_TEXTAREA_FLEXIBLE_PARENT', 'textarea-flexible-parent');
